==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ImagesChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ImagesChangedEventArgsDescription } from "./ImagesChangedEventArgsDescription";
/**
 * @hidden
 */
var ImagesChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ImagesChangedEventArgsDescriptionMetadata, _super);
    function ImagesChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ImagesChangedEventArgsDescriptionMetadata.b = function (a) {
        if (ImagesChangedEventArgsDescriptionMetadata.a == null) {
            ImagesChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ImagesChangedEventArgsDescriptionMetadata.c(ImagesChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(ImagesChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ImagesChangedEventArgsDescriptionMetadata.a);
    };
    ImagesChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    ImagesChangedEventArgsDescriptionMetadata.d = function (a) {
        ImagesChangedEventArgsDescriptionMetadata.b(a);
        a.u("ImagesChangedEventArgs", function () { return new ImagesChangedEventArgsDescription(); });
        a.t("ImagesChangedEventArgs", ImagesChangedEventArgsDescriptionMetadata.a);
    };
    ImagesChangedEventArgsDescriptionMetadata.$t = markType(ImagesChangedEventArgsDescriptionMetadata, 'ImagesChangedEventArgsDescriptionMetadata');
    ImagesChangedEventArgsDescriptionMetadata.a = null;
    return ImagesChangedEventArgsDescriptionMetadata;
}(Base));
export { ImagesChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ImagesChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ImagesChangedEventArgsDescription } from "./ImagesChangedEventArgsDescription";
/**
 * @hidden
 */
var ImagesChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ImagesChangedEventArgsDescriptionMetadata, _super);
    function ImagesChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ImagesChangedEventArgsDescriptionMetadata.b = function (a) {
        if (ImagesChangedEventArgsDescriptionMetadata.a == null) {
            ImagesChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ImagesChangedEventArgsDescriptionMetadata.c(ImagesChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(ImagesChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ImagesChangedEventArgsDescriptionMetadata.a);
    };
    ImagesChangedEventArgsDescriptionMetadata.c = function (a) {
    };
    ImagesChangedEventArgsDescriptionMetadata.d = function (a) {
        ImagesChangedEventArgsDescriptionMetadata.b(a);
        a.aa("ImagesChangedEventArgs", function () { return new ImagesChangedEventArgsDescription(); });
        a.z("ImagesChangedEventArgs", ImagesChangedEventArgsDescriptionMetadata.a);
    };
    ImagesChangedEventArgsDescriptionMetadata.$t = markType(ImagesChangedEventArgsDescriptionMetadata, 'ImagesChangedEventArgsDescriptionMetadata');
    ImagesChangedEventArgsDescriptionMetadata.a = null;
    return ImagesChangedEventArgsDescriptionMetadata;
}(Base));
export { ImagesChangedEventArgsDescriptionMetadata };
